@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,13 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-from google.rpc import status_pb2 as status  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+from google.rpc import status_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -87,11 +84,9 @@ class Reservation(proto.Message):
             slot capacity specified above at most.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    slot_capacity = proto.Field(proto.INT64, number=2)
-
-    ignore_idle_slots = proto.Field(proto.BOOL, number=4)
+    name = proto.Field(proto.STRING, number=1,)
+    slot_capacity = proto.Field(proto.INT64, number=2,)
+    ignore_idle_slots = proto.Field(proto.BOOL, number=4,)
 
 
 class CapacityCommitment(proto.Message):
@@ -151,20 +146,14 @@ class CapacityCommitment(proto.Message):
         ACTIVE = 2
         FAILED = 3
 
-    name = proto.Field(proto.STRING, number=1)
-
-    slot_count = proto.Field(proto.INT64, number=2)
-
+    name = proto.Field(proto.STRING, number=1,)
+    slot_count = proto.Field(proto.INT64, number=2,)
     plan = proto.Field(proto.ENUM, number=3, enum=CommitmentPlan,)
-
     state = proto.Field(proto.ENUM, number=4, enum=State,)
-
     commitment_end_time = proto.Field(
-        proto.MESSAGE, number=5, message=timestamp.Timestamp,
+        proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,
     )
-
-    failure_status = proto.Field(proto.MESSAGE, number=7, message=status.Status,)
-
+    failure_status = proto.Field(proto.MESSAGE, number=7, message=status_pb2.Status,)
     renewal_plan = proto.Field(proto.ENUM, number=8, enum=CommitmentPlan,)
 
 
@@ -184,10 +173,8 @@ class CreateReservationRequest(proto.Message):
             Definition of the new reservation to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    reservation_id = proto.Field(proto.STRING, number=2)
-
+    parent = proto.Field(proto.STRING, number=1,)
+    reservation_id = proto.Field(proto.STRING, number=2,)
     reservation = proto.Field(proto.MESSAGE, number=3, message="Reservation",)
 
 
@@ -207,11 +194,9 @@ class ListReservationsRequest(proto.Message):
             request, if any.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
 
 
 class ListReservationsResponse(proto.Message):
@@ -232,8 +217,7 @@ class ListReservationsResponse(proto.Message):
         return self
 
     reservations = proto.RepeatedField(proto.MESSAGE, number=1, message="Reservation",)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class GetReservationRequest(proto.Message):
@@ -247,7 +231,7 @@ class GetReservationRequest(proto.Message):
             ``projects/myproject/locations/US/reservations/team1-prod``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class DeleteReservationRequest(proto.Message):
@@ -261,7 +245,7 @@ class DeleteReservationRequest(proto.Message):
             ``projects/myproject/locations/US/reservations/team1-prod``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class UpdateReservationRequest(proto.Message):
@@ -277,8 +261,9 @@ class UpdateReservationRequest(proto.Message):
     """
 
     reservation = proto.Field(proto.MESSAGE, number=1, message="Reservation",)
-
-    update_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask.FieldMask,)
+    update_mask = proto.Field(
+        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    )
 
 
 class CreateCapacityCommitmentRequest(proto.Message):
@@ -296,13 +281,11 @@ class CreateCapacityCommitmentRequest(proto.Message):
             in the organization has a capacity commitment.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     capacity_commitment = proto.Field(
         proto.MESSAGE, number=2, message="CapacityCommitment",
     )
-
-    enforce_single_admin_project_per_org = proto.Field(proto.BOOL, number=4)
+    enforce_single_admin_project_per_org = proto.Field(proto.BOOL, number=4,)
 
 
 class ListCapacityCommitmentsRequest(proto.Message):
@@ -320,11 +303,9 @@ class ListCapacityCommitmentsRequest(proto.Message):
             request, if any.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
 
 
 class ListCapacityCommitmentsResponse(proto.Message):
@@ -348,8 +329,7 @@ class ListCapacityCommitmentsResponse(proto.Message):
     capacity_commitments = proto.RepeatedField(
         proto.MESSAGE, number=1, message="CapacityCommitment",
     )
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class GetCapacityCommitmentRequest(proto.Message):
@@ -363,7 +343,7 @@ class GetCapacityCommitmentRequest(proto.Message):
             ``projects/myproject/locations/US/capacityCommitments/123``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class DeleteCapacityCommitmentRequest(proto.Message):
@@ -377,7 +357,7 @@ class DeleteCapacityCommitmentRequest(proto.Message):
             ``projects/myproject/locations/US/capacityCommitments/123``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class UpdateCapacityCommitmentRequest(proto.Message):
@@ -395,8 +375,9 @@ class UpdateCapacityCommitmentRequest(proto.Message):
     capacity_commitment = proto.Field(
         proto.MESSAGE, number=1, message="CapacityCommitment",
     )
-
-    update_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask.FieldMask,)
+    update_mask = proto.Field(
+        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    )
 
 
 class SplitCapacityCommitmentRequest(proto.Message):
@@ -412,9 +393,8 @@ class SplitCapacityCommitmentRequest(proto.Message):
             after the split.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    slot_count = proto.Field(proto.INT64, number=2)
+    name = proto.Field(proto.STRING, number=1,)
+    slot_count = proto.Field(proto.INT64, number=2,)
 
 
 class SplitCapacityCommitmentResponse(proto.Message):
@@ -430,7 +410,6 @@ class SplitCapacityCommitmentResponse(proto.Message):
     """
 
     first = proto.Field(proto.MESSAGE, number=1, message="CapacityCommitment",)
-
     second = proto.Field(proto.MESSAGE, number=2, message="CapacityCommitment",)
 
 
@@ -452,9 +431,8 @@ class MergeCapacityCommitmentsRequest(proto.Message):
             projects/myproject/locations/US/capacityCommitments/abc
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    capacity_commitment_ids = proto.RepeatedField(proto.STRING, number=2)
+    parent = proto.Field(proto.STRING, number=1,)
+    capacity_commitment_ids = proto.RepeatedField(proto.STRING, number=2,)
 
 
 class Assignment(proto.Message):
@@ -492,12 +470,9 @@ class Assignment(proto.Message):
         PENDING = 1
         ACTIVE = 2
 
-    name = proto.Field(proto.STRING, number=1)
-
-    assignee = proto.Field(proto.STRING, number=4)
-
+    name = proto.Field(proto.STRING, number=1,)
+    assignee = proto.Field(proto.STRING, number=4,)
     job_type = proto.Field(proto.ENUM, number=3, enum=JobType,)
-
     state = proto.Field(proto.ENUM, number=6, enum=State,)
 
 
@@ -515,8 +490,7 @@ class CreateAssignmentRequest(proto.Message):
             Assignment resource to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     assignment = proto.Field(proto.MESSAGE, number=2, message="Assignment",)
 
 
@@ -541,11 +515,9 @@ class ListAssignmentsRequest(proto.Message):
             request, if any.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
 
 
 class ListAssignmentsResponse(proto.Message):
@@ -566,8 +538,7 @@ class ListAssignmentsResponse(proto.Message):
         return self
 
     assignments = proto.RepeatedField(proto.MESSAGE, number=1, message="Assignment",)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class DeleteAssignmentRequest(proto.Message):
@@ -582,7 +553,7 @@ class DeleteAssignmentRequest(proto.Message):
             ``projects/myproject/locations/US/reservations/team1-prod/assignments/123``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class SearchAssignmentsRequest(proto.Message):
@@ -612,13 +583,10 @@ class SearchAssignmentsRequest(proto.Message):
             request, if any.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    query = proto.Field(proto.STRING, number=2)
-
-    page_size = proto.Field(proto.INT32, number=3)
-
-    page_token = proto.Field(proto.STRING, number=4)
+    parent = proto.Field(proto.STRING, number=1,)
+    query = proto.Field(proto.STRING, number=2,)
+    page_size = proto.Field(proto.INT32, number=3,)
+    page_token = proto.Field(proto.STRING, number=4,)
 
 
 class SearchAssignmentsResponse(proto.Message):
@@ -639,8 +607,7 @@ class SearchAssignmentsResponse(proto.Message):
         return self
 
     assignments = proto.RepeatedField(proto.MESSAGE, number=1, message="Assignment",)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class MoveAssignmentRequest(proto.Message):
@@ -663,14 +630,12 @@ class MoveAssignmentRequest(proto.Message):
             ``projects/myotherproject/locations/US/reservations/team2-prod``
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    destination_id = proto.Field(proto.STRING, number=3)
+    name = proto.Field(proto.STRING, number=1,)
+    destination_id = proto.Field(proto.STRING, number=3,)
 
 
 class BiReservation(proto.Message):
     r"""Represents a BI Reservation.
-
     Attributes:
         name (str):
             The resource name of the singleton BI reservation.
@@ -683,28 +648,24 @@ class BiReservation(proto.Message):
             Size of a reservation, in bytes.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
-
-    size = proto.Field(proto.INT64, number=4)
+    name = proto.Field(proto.STRING, number=1,)
+    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
+    size = proto.Field(proto.INT64, number=4,)
 
 
 class GetBiReservationRequest(proto.Message):
     r"""A request to get a singleton BI reservation.
-
     Attributes:
         name (str):
             Required. Name of the requested reservation, for example:
             ``projects/{project_id}/locations/{location_id}/bireservation``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class UpdateBiReservationRequest(proto.Message):
     r"""A request to update a BI reservation.
-
     Attributes:
         bi_reservation (google.cloud.bigquery_reservation_v1.types.BiReservation):
             A reservation to update.
@@ -714,8 +675,9 @@ class UpdateBiReservationRequest(proto.Message):
     """
 
     bi_reservation = proto.Field(proto.MESSAGE, number=1, message="BiReservation",)
-
-    update_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask.FieldMask,)
+    update_mask = proto.Field(
+        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
